
#ifndef KLDAPWIDGETS_EXPORT_H
#define KLDAPWIDGETS_EXPORT_H

#ifdef KLDAPWIDGETS_STATIC_DEFINE
#  define KLDAPWIDGETS_EXPORT
#  define KLDAPWIDGETS_NO_EXPORT
#else
#  ifndef KLDAPWIDGETS_EXPORT
#    ifdef KPim6LdapWidgets_EXPORTS
        /* We are building this library */
#      define KLDAPWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KLDAPWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KLDAPWIDGETS_NO_EXPORT
#    define KLDAPWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KLDAPWIDGETS_DEPRECATED
#  define KLDAPWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KLDAPWIDGETS_DEPRECATED_EXPORT
#  define KLDAPWIDGETS_DEPRECATED_EXPORT KLDAPWIDGETS_EXPORT KLDAPWIDGETS_DEPRECATED
#endif

#ifndef KLDAPWIDGETS_DEPRECATED_NO_EXPORT
#  define KLDAPWIDGETS_DEPRECATED_NO_EXPORT KLDAPWIDGETS_NO_EXPORT KLDAPWIDGETS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KLDAPWIDGETS_NO_DEPRECATED
#    define KLDAPWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* KLDAPWIDGETS_EXPORT_H */
