// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KLDAPWIDGETS_VERSION_H
#define KLDAPWIDGETS_VERSION_H

#define KLDAPWIDGETS_VERSION_STRING "6.7.0"
#define KLDAPWIDGETS_VERSION_MAJOR 6
#define KLDAPWIDGETS_VERSION_MINOR 7
#define KLDAPWIDGETS_VERSION_PATCH 0
#define KLDAPWIDGETS_VERSION ((6<<16)|(7<<8)|(0))

#endif
